@@ -5,7 +5,7 @@
  * This file defines Horde's core API interface. Other core Horde libraries
  * can interact with Content through this API.
  *
- * Copyright 2011-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
  *
  * @license  http://www.horde.org/licenses/bsd BSD
  * @package Content
@@ -13,7 +13,7 @@
 
 /* Determine the base directories. */
 if (!defined('CONTENT_BASE')) {
-    define('CONTENT_BASE', __DIR__ . '/..');
+    define('CONTENT_BASE', realpath(__DIR__ . '/..'));
 }
 
 if (!defined('HORDE_BASE')) {
@@ -22,7 +22,7 @@ if (!defined('HORDE_BASE')) {
     if (file_exists(CONTENT_BASE . '/config/horde.local.php')) {
         include CONTENT_BASE . '/config/horde.local.php';
     } else {
-        define('HORDE_BASE', CONTENT_BASE . '/..');
+        define('HORDE_BASE', realpath(CONTENT_BASE . '/..'));
     }
 }
 
@@ -34,5 +34,5 @@ class Content_Application extends Horde_Registry_Application
 {
     /**
      */
-    public $version = '2.0.3';
+    public $version = '2.0.4';
 }
