@@ -5,7 +5,7 @@
 require_once __DIR__ . '/Base.php';
 
 /**
- * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
  *
  * @author     Jan Schneider <jan@horde.org>
  * @category   Horde
@@ -21,10 +21,10 @@ class Content_Sql_MysqliTest extends Content_Test_Sql_Base
             self::$reason = 'No mysqli extension';
             return;
         }
-        $config = self::getConfig('GROUP_SQL_MYSQLI_TEST_CONFIG',
+        $config = self::getConfig('CONTENT_SQL_MYSQLI_TEST_CONFIG',
                                   __DIR__ . '/..');
-        if ($config && !empty($config['group']['sql']['mysqli'])) {
-            self::$db = new Horde_Db_Adapter_Mysqli($config['group']['sql']['mysqli']);
+        if ($config && !empty($config['content']['sql']['mysqli'])) {
+            self::$db = new Horde_Db_Adapter_Mysqli($config['content']['sql']['mysqli']);
             parent::setUpBeforeClass();
         }
     }
